pepys\_import.core.formats package
==================================

Submodules
----------

pepys\_import.core.formats.file\_data module
--------------------------------------------

.. automodule:: pepys_import.core.formats.file_data
   :members:
   :undoc-members:
   :show-inheritance:

pepys\_import.core.formats.location module
------------------------------------------

.. automodule:: pepys_import.core.formats.location
   :members:
   :undoc-members:
   :show-inheritance:

pepys\_import.core.formats.repl\_file module
--------------------------------------------

.. automodule:: pepys_import.core.formats.repl_file
   :members:
   :undoc-members:
   :show-inheritance:

pepys\_import.core.formats.state module
---------------------------------------

.. automodule:: pepys_import.core.formats.state
   :members:
   :undoc-members:
   :show-inheritance:

pepys\_import.core.formats.unit\_conversion module
--------------------------------------------------

.. automodule:: pepys_import.core.formats.unit_conversion
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: pepys_import.core.formats
   :members:
   :undoc-members:
   :show-inheritance:
